==> qtermwidget_0.16.1.orig.tar.xz: qtermwidget-0.16.1/lib/translations/qtermwidget_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr_HR">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="454"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="606"/>
        <source>Session &apos;%1&apos; exited with status %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="608"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="613"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1282"/>
        <source>Size: XXX x XXX</source>
        <translation>Veličina: XXX × XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1294"/>
        <source>Size: %1 x %2</source>
        <translation>Veličina: %1 × %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3180"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Rezultat je &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;obustavljen&lt;/a&gt; pritiskom Ctrl+S. Pritisni &lt;b&gt;Ctrl+Q&lt;/b&gt; za nastavak.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1113"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Nema interpretera tipkovnice. Nedostaju podaci za pretvaranje tipki u znakove koji se šalju u terminal.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="278"/>
        <location filename="../ColorScheme.cpp" line="293"/>
        <source>Un-named Color Scheme</source>
        <translation>Neimenovana shema boja</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="464"/>
        <source>Accessible Color Scheme</source>
        <translation>Dostupna shema boja</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="515"/>
        <source>Open Link</source>
        <translation>Otvori poveznicu</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="516"/>
        <source>Copy Link Address</source>
        <translation>Otvori adresu poveznice</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="520"/>
        <source>Send Email To...</source>
        <translation>Pošalji e-mail na …</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="521"/>
        <source>Copy Email Address</source>
        <translation>Kopiraj e-adresu</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="459"/>
        <source>Color Scheme Error</source>
        <translation>Greška u shemi boja</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="460"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Nije moguće učitati shemu boja: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>Razlikuj velika/mala slova</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>Regularni izrazi</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>Istakni sva poklapanja</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Traka pretrage</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Traži:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>…</translation>
    </message>
</context>
</TS>

==> qtermwidget_1.2.0.orig.tar.xz: qtermwidget-1.2.0/lib/translations/qtermwidget_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr_HR">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="454"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation>Zvono u sesiji „%1“</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="606"/>
        <source>Session &apos;%1&apos; exited with status %2.</source>
        <translation>Sesija „%1“ je prekinuta sa stanjem %2.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="608"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation>Fatalna greška u sesiji „%1“.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="613"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation>Sesija „%1“ je nenadano prekinuta.</translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1277"/>
        <source>Size: XXX x XXX</source>
        <translation>Veličina: XXX × XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1289"/>
        <source>Size: %1 x %2</source>
        <translation>Veličina: %1 × %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2789"/>
        <source>Paste multiline text</source>
        <translation>Umetni višeredan tekst</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2790"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>Stvarno želiš umetnuti ovaj tekst?</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3260"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Rezultat je &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;obustavljen&lt;/a&gt; pritiskom Ctrl+S. Pritisni &lt;b&gt;Ctrl+Q&lt;/b&gt; za nastavak.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1121"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Nema interpretera tipkovnice. Nedostaju podaci za pretvaranje tipki u znakove koji se šalju u terminal.</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2796"/>
        <source>Show Details...</source>
        <translation>Prikaži detalje …</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="275"/>
        <location filename="../ColorScheme.cpp" line="290"/>
        <source>Un-named Color Scheme</source>
        <translation>Neimenovana shema boja</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="461"/>
        <source>Accessible Color Scheme</source>
        <translation>Dostupna shema boja</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="515"/>
        <source>Open Link</source>
        <translation>Otvori poveznicu</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="516"/>
        <source>Copy Link Address</source>
        <translation>Otvori adresu poveznice</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="520"/>
        <source>Send Email To...</source>
        <translation>Pošalji e-mail na …</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="521"/>
        <source>Copy Email Address</source>
        <translation>Kopiraj e-adresu</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="464"/>
        <source>Color Scheme Error</source>
        <translation>Greška u shemi boja</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="465"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Nije moguće učitati shemu boja: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>Razlikuj velika/mala slova</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>Regularni izrazi</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>Istakni sva poklapanja</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Traka pretrage</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Traži:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>…</translation>
    </message>
</context>
</TS>
